pub(crate) struct PendingCommandExecutionQueue<S>where
S: ExecutionCommandSource,{
queued: VecDeque<PendingCommandExecution<S>>,
blocked_sources: FxHashMap<CommandSenderKey, usize>,
global_barriers: usize,
}Expand description
Suspended command executions owned by the server tick.
Fields
queued: VecDeque<PendingCommandExecution<S>>blocked_sources: FxHashMap<CommandSenderKey, usize>global_barriers: usizeImplementations
Sourceimpl<S> PendingCommandExecutionQueue<S>where
S: ExecutionCommandSource,
impl<S> PendingCommandExecutionQueue<S>where
S: ExecutionCommandSource,
pub(crate) fn new() -> Self
Sourcepub(crate) fn push_suspended(
&mut self,
owner: CommandExecutionOwner,
execution: CommandExecutionContext<S>,
) -> bool
pub(crate) fn push_suspended( &mut self, owner: CommandExecutionOwner, execution: CommandExecutionContext<S>, ) -> bool
Retains an execution only when it is waiting on suspended work.
Sourcepub(crate) fn blocks(&self, source: CommandSenderKey) -> bool
pub(crate) fn blocks(&self, source: CommandSenderKey) -> bool
Returns whether a later top-level command from source must wait.
Sourcepub(crate) fn tick(
&mut self,
limit: usize,
owner_is_current: impl FnMut(&CommandExecutionOwner) -> bool,
) -> PendingCommandExecutionStats
pub(crate) fn tick( &mut self, limit: usize, owner_is_current: impl FnMut(&CommandExecutionOwner) -> bool, ) -> PendingCommandExecutionStats
Polls each execution selected for this tick at most once, preserving FIFO order.
pub(crate) fn cancel_all(&mut self)
fn retain_barrier( &mut self, source: CommandSenderKey, order: CommandSuspensionOrder, )
fn release_barrier( &mut self, source: CommandSenderKey, order: CommandSuspensionOrder, )